==> pyPrairieView-0.0.0.tar.gz: pyPrairieView-0.0.0/README.md <==
## pyPrairieView
<!-- Line 1 Badges... PyPi, Downloads, Maintained, Coverage, Documentation -->
<!-- Line 2 Badges... Python Versions, PyPi Status, License, Contributors-->
![PyPI](https://img.shields.io/pypi/v/pyPrairieView)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pyPrairieView)
![Maintenance](https://img.shields.io/maintenance/yes/2023)
![Coveralls branch](https://img.shields.io/coverallsCoverage/github/saglag/pyPrairieView?branch=master)
[![Documentation Status](https://readthedocs.org/projects/pyprairieview/badge/?version=latest)](https://pyprairieview.readthedocs.io/en/latest/?badge=latest)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyPrairieView?)
![PyPI - Status](https://img.shields.io/pypi/status/pyPrairieView)
![GitHub](https://img.shields.io/github/license/saglag/pyPrairieView)
[![Contributors](https://img.shields.io/github/contributors-anon/saglag/pyPrairieView)](https://github.com/saglag/pyPrairieView/graphs/contributors)
[![pyPrairieView Linting and Testing](https://github.com/saglag/pyPrairieView/actions/workflows/pyprairieview_lint_test.yml/badge.svg)](https://github.com/saglag/pyPrairieView/actions/workflows/pyprairieview_lint_test.yml)

 A Python libary for interacting with PrarieView software.
 
 #### Highlights (Aspirational) 
- Electrophysiology protocol design
- Electrophysiology analysis (initially dependent on protocol design)
- Metadata handling of XML files
- Imaging file compilation
- Data stream generation
- Online motion correction
- ROI-Mark Points translation

More to come in the future!

#### Installation
`pip install pyPrairieView`

#### Documentation
Hosted at [ReadtheDocs](https://pyprairieview.readthedocs.io/en/latest/index.html#).
Available locally as [HTML](https://github.com/saglag/pyPrairieView/tree/master/docs/build/html), [LATEX](https://github.com/saglag/pyPrairieView/tree/master/docs/build/latex) and [PDF](https://github.com/saglag/pyPrairieView/blob/master/docs/build/pdf/pyprairieview.pdf).

==> pyPrairieView-0.0.1.tar.gz: pyPrairieView-0.0.1/README.md <==
## pyPrairieView
<!-- Line 1 Badges... PyPi, Downloads, Maintained, Coverage, Documentation -->
<!-- Line 2 Badges... Python Versions, PyPi Status, License, Contributors-->
![PyPI](https://img.shields.io/pypi/v/pyPrairieView)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pyPrairieView)
![Maintenance](https://img.shields.io/maintenance/yes/2023)
![Coveralls branch](https://img.shields.io/coverallsCoverage/github/saglag/pyPrairieView?branch=master)
[![Documentation Status](https://readthedocs.org/projects/pyprairieview/badge/?version=latest)](https://pyprairieview.readthedocs.io/en/latest/?badge=latest)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyPrairieView?)
![PyPI - Status](https://img.shields.io/pypi/status/pyPrairieView)
![GitHub](https://img.shields.io/github/license/saglag/pyPrairieView)
[![Contributors](https://img.shields.io/github/contributors-anon/saglag/pyPrairieView)](https://github.com/saglag/pyPrairieView/graphs/contributors)
[![Linting and Testing](https://github.com/saglag/pyPrairieView/actions/workflows/pyprairieview_lint_test.yml/badge.svg)](https://github.com/saglag/pyPrairieView/actions/workflows/pyprairieview_lint_test.yml)

 A Python libary for interacting with PrarieView software.
 
 #### Highlights (Aspirational) 
- Electrophysiology protocol design
- Electrophysiology analysis (initially dependent on protocol design)
- Metadata handling of XML files
- Imaging file compilation
- Data stream generation
- Online motion correction
- ROI-Mark Points translation

More to come in the future!

#### Installation
`pip install pyPrairieView`

#### Documentation
Hosted at [ReadtheDocs](https://pyprairieview.readthedocs.io/en/latest/index.html#).
Available locally as [HTML](https://github.com/saglag/pyPrairieView/tree/master/docs/build/html), [LATEX](https://github.com/saglag/pyPrairieView/tree/master/docs/build/latex) and [PDF](https://github.com/saglag/pyPrairieView/blob/master/docs/build/pdf/pyprairieview.pdf).
